from plug_email_chase import utils

__docformat__ = "restructuredtext"

__version__ = "1.0.1"

# module level doc-string
__doc__ = """
plug_email_chase - a Python data pipeline for Chase Bank data from email
========================================================================

**plug_email_chase** is a Python package providing a data pipeline for Chase Bank data
pulled from the email

Main Features
-------------
Here are just a few of the things that plug_email_chase does well:

"""

if __name__ == "__main__":
    import doctest

    doctest.testmod()



"""
plug_email_chase extract
------------------------
The Extract Submodule

Date: 2021-05-14

Author: Lorenzo Coacci
"""
from bs4 import BeautifulSoup

# + + + Libraries + + +
# to manage basic
from golog import (
    correct_nonlist,
    dict_print,
    error_print,
    filepath_exists,
    is_url,
    print_magenta,
    se,
    sev,
    warning_print,
)

# + + + Libraries + + +


# + + + Settings + + +
# + + + Settings + + +


# + + + Functions + + +
# + + + Functions + + +


# + + + Classes + + +
def extract():
    pass


class Example:
    """
    Example : the Example Object

    A Example class to manage a Google Mail


    Parameters
    ----------
    example_creds_path (optional): string
        The G Mail Path to the client secret JSON
    example_config_path (optional): string
        The G Mail Path to the token.pickle
    example_client (optional): exampleClient
        The exampleClient Object if already exists
    debug (optional): bool
        Show debug info?
    base_email (optional): string
        The base email
    base_url (optional): string
        The base url
    scopes (optional): list of strings
        The list with API scopes
    api_version (optional): string
        The API version


    See Also
    --------
    TODO: see also

    Examples
    --------

    >>> example = example(example_config_path='./token.pickle')

    >>>
    """

    def __init__(
        self,
        example_creds_path=None,
        example_config_path=None,
        example_client=None,
        debug=False,
        base_email="me",
        base_url="https://mail.google.com/mail/u/4",
        scopes=None,
        api_version="v1",
    ):
        """Init example"""
        self.debug = bool(debug)
        self.base_email = str(base_email)
        self.base_url = str(base_url)
        self.api_version = str(api_version)

        # load client
        if example_client is not None:
            self.client = example_client

        self.example = self.client


# + + + Classes + + +



"""
plug_email_chase utils
----------------------
The utils module

Date: 2021-05-14

Author: Lorenzo Coacci
"""
# + + + Libraries + + +
import json
import os
# + + + Libraries + + +


# + + + Settings + + +
# + + + Settings + + +


# + + + Functions + + +
# - - Plug Config - -
def parse_plug_config(config_path: str) -> dict:
    """RETURN a dict from the parsed json config"""
    # clean config input
    config_path = str(config_path)
    check = os.path.exists(config_path)
    if not check:
        raise f"Plug Config filepath does not exist: {config_path}"

    with open(config_path, 'r') as f:
        config = json.loads(f.read())

    return config

# - - Plug Catalog - -

# - - Plug Target - -

# - - Plug State - -

# + + + Functions + + +



#!/usr/bin/env python

import re
from setuptools import setup, find_packages
import subprocess


def long_description():
    with open("README.md", "r", encoding="utf-8") as f:
        readme = f.read()
    return readme


def license():
    with open("LICENSE", "r", encoding="utf-8") as f:
        license = f.read()
    return license


setup(
    name="plug-email-chase",
    version="1.0.1",
    description="Plug - Email Chase Pipeline",
    author="Lorenzo Coacci",
    author_email="lorenzo@coacci.it",
    long_description_content_type="text/markdown",
    long_description=long_description(),
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
    ],
    keywords=["data pipeline", "etl", "data engineering"],
    license=license(),
    url="https://github.com/lollococce/plug-email-chase",
    include_package_data=True,
    install_requires=[
        "pytz==2018.4",
        "jsonschema==2.6.0",
        "simplejson==3.11.1",
        "python-dateutil>=2.6.0",
        "backoff==1.8.0",
        "ciso8601",
    ],
    extras_require={"dev": ["pylint", "ipython", "ipdb", "nose"]},
    packages=find_packages(exclude=("tests", "tests.*", "docs", "docs.*")),
    package_data={"singer": ["logging.conf"]},
    zip_safe=False,
)
